@@ -6,6 +6,7 @@ from sdccli.cli.capture import capture
 from sdccli.cli.command import command
 from sdccli.cli.compliance import compliance
 from sdccli.cli.dashboard import dashboard
+from sdccli.cli.eventv1 import eventv1
 from sdccli.cli.event import event
 from sdccli.cli.policy import policy
 from sdccli.cli.scanning import scanning
@@ -47,6 +48,7 @@ cli.add_command(capture)
 cli.add_command(command)
 cli.add_command(compliance)
 cli.add_command(dashboard)
+cli.add_command(eventv1)
 cli.add_command(event)
 cli.add_command(policy)
 cli.add_command(scanning)
