@@ -1,9 +1,12 @@
-import click
 import json
 import sys
+from datetime import datetime
+
+import click
 from prettytable import PrettyTable, PLAIN_COLUMNS
+
 from sdccli.printer import print_item
-from sdccli.time import date_range_in_sec, format_timestamp
+from sdccli.time import format_timestamp, duration_to_timedelta
 
 
 @click.group(name='event', short_help="Sysdig Monitor events operations")
@@ -14,9 +17,11 @@ def event():
 @event.command(name='add', short_help="Add an event")
 @click.argument('name', nargs=1)
 @click.option('--description', nargs=1, help="a longer description offering detailed information about the event.")
-@click.option('--severity', nargs=1, type=click.INT, help="syslog style from 0 (high) to 7 (low).")
-@click.option('--filter', nargs=1, help="metadata, in Sysdig Monitor format, of nodes to associate with the event, e.g. ``host.hostName = 'ip-10-1-1-1' and container.name = 'foo'``.")
-@click.option('--tag', nargs=1, help="A key=value that can be used to tag the event. Can be used for filtering/segmenting purposes in Sysdig Monitor.")
+@click.option('--severity', nargs=1, type=click.INT, help="syslog style from 0 (high) to 3 (low).")
+@click.option('--filter', nargs=1,
+              help="metadata, in Sysdig Monitor format, of nodes to associate with the event, e.g. ``host.hostName = 'ip-10-1-1-1' and container.name = 'foo'``.")
+@click.option('--tag', nargs=1,
+              help="A key=value that can be used to tag the event. Can be used for filtering/segmenting purposes in Sysdig Monitor.")
 @click.pass_obj
 def add(cnf, name, description, severity, filter, tag):
     """
@@ -32,6 +37,10 @@ def add(cnf, name, description, severity, filter, tag):
                 return
             tags[k] = v
 
+    if severity is not None and not -1 < severity < 4:
+        print("The severity values must be between 0 (high) and 3 (low), both included.")
+        sys.exit(1)
+
     ok, res = cnf.sdmonitor.post_event(
         name,
         description=description,
@@ -52,26 +61,24 @@ def add(cnf, name, description, severity, filter, tag):
 
 @event.command(name='list', short_help="List all events")
 @click.option('--duration', nargs=1, help="Duration to display the events from. (ex: 30M, 1H, 3D, 2W)")
-@click.option('--start', nargs=1, help="Start of the time range.")
-@click.option('--end', nargs=1, help="End of the time range.")
+@click.option('--limit', nargs=1, type=int, help="Max number of events to print. Default: 100")
 @click.option('--name', nargs=1, help="Filter events by name.")
 @click.pass_obj
-def list(cnf, duration, start, end, name):
-    from_sec, to_sec = None, None
-    if duration or start or end:
-        try:
-            from_sec, to_sec = date_range_in_sec(start, end, duration)
-        except IndexError as ex:
-            print("Error: {}".format(ex))
-            sys.exit(1)
+def list_events(cnf, duration, limit, name):
+    from_sec = to_sec = None
+    if duration is not None:
+        delta = duration_to_timedelta(duration)
+        to_sec = datetime.now()
+        from_sec = to_sec - delta
 
-        from_sec = int(from_sec)
-        to_sec = int(to_sec)
+    if limit is None:
+        limit = 100
 
     ok, res = cnf.sdmonitor.get_events(
         name=name,
-        from_ts=from_sec,
-        to_ts=to_sec)
+        from_s=from_sec,
+        to_s=to_sec,
+        limit=limit)
 
     if cnf.json:
         print(json.dumps(res, indent=4))
@@ -119,7 +126,7 @@ def delete(cnf, events):
     EVENTS: Event ids to delete
     """
     for event in events:
-        ok, res = cnf.sdsecure.delete_event({"id": event})
+        ok, res = cnf.sdmonitor.delete_event({"id": event})
 
         if not ok:
             print("Error: " + str(res))
@@ -136,11 +143,13 @@ def _print_events(events):
     for event in events:
         values = []
         values.append(event["id"])
-        values.append(event["severityLabel"])
+        values.append(event["severity"])
         values.append(event["name"])
         values.append(format_timestamp(event["timestamp"]))
-        if "tags" in event and "source" in event["tags"]:
-            values.append(event["tags"]["source"])
+        if "source" in event:
+            values.append(event["source"])
+        elif "type" in event and event["type"]:
+            values.append(event["type"].lower())
         else:
             values.append("NONE")
         t.add_row(values)
