@@ -1,4 +1,4 @@
-from sdccli.cli.formatter.text_formatter import alert, dashboard, panel
+from sdccli.cli.formatter.text_formatter import alert, dashboard, panel, policy_events
 from sdccli.cli.formatter.text_formatter.scanning import alert as scanning_alert
 from sdccli.cli.formatter.text_formatter.scanning import image, vulnerability
 
@@ -12,6 +12,7 @@ class NormalFormatter:
         self.formats.update(image.formats())
         self.formats.update(panel.formats())
         self.formats.update(vulnerability.formats())
+        self.formats.update(policy_events.formats())
 
     def format(self, response, format_type):
         if format_type in self.formats:
