@@ -1,4 +1,6 @@
 import click
+
+from sdccli.cli.scanning.vulnerability import vulnerability
 from sdccli.cli.scanning.image import image
 from sdccli.cli.scanning.registry import registry
 from sdccli.cli.scanning.repo import repo
@@ -24,3 +26,4 @@ scanning.add_command(alert)
 scanning.add_command(runtime)
 scanning.add_command(query)
 scanning.add_command(cve_report)
+scanning.add_command(vulnerability)
\ No newline at end of file
