@@ -71,7 +71,7 @@ def alerts(file_data, monitor: SdMonitorClient):
     for i, alert in enumerate(file_data, start=1):
         name = alert['name']
         alert['notificationChannelIds'] = []
-        for nc in alert['notificationChannelNames']:
+        for nc in alert.get('notificationChannelNames', []):
             if nc in existing_notification_channels:
                 alert['notificationChannelIds'].append(existing_notification_channels[nc])
             else:
